shithub: choc

Download patch

ref: 76b6d1a239ddda25a8645ac0e94d45884b71fa5a
parent: a0104247691296ef80807f7e55183a751fa69db8
author: James Haley <haleyjd@hotmail.com>
date: Sun Oct 26 16:29:18 EDT 2014

Another teleport beacon correction

Flag to be cleared is MF_SPECIAL, not MF_SOLID (verified against
disassembly). Otherwise you get to spawn an infinite number of rebels
from one beacon. Not to mention, it isn't SOLID to start with.

--- a/src/strife/p_enemy.c
+++ b/src/strife/p_enemy.c
@@ -3174,8 +3174,8 @@
         return;
     }
 
-    // beacon no longer solid
-    actor->flags &= ~MF_SOLID;
+    // beacon no longer special
+    actor->flags &= ~MF_SPECIAL;
 
     // set color and flags
     mobj->flags |= ((actor->miscdata << MF_TRANSSHIFT) | MF_NODIALOG);